@@ -41,7 +41,10 @@ class Network3Medusa():
             if WEBEX_ROOM:
                 self.send_webex_notification()
         elif self.command == "show running-config":
-            print(raw_json)
+            for line in raw_json.split('\n'):
+                print("new")
+                print(line)
+
         else:
             self.add_file_to_hedera(raw_json)
             if WEBEX_ROOM:
